@@ -1,6 +1,5 @@
 load("data/nrc.rda")
+load("data/stop_words.rda")
 utils::globalVariables(c("text", "word_occur", "key", "n", "word", "sentiment",
-                         "exist", "desc", "nrc"))
-
-
+                         "exist", "desc", "nrc", "data", "word1", "word2"))
 
